@@ -39,7 +39,7 @@ import com.openexchange.admin.soap.user.dataobjects.UserModuleAccess;
     "ctx",
     "usrdata",
     "access",
-    "auth"
+    "auth",
 })
 @XmlRootElement(name = "createByModuleAccess")
 public class CreateByModuleAccess {
